base3rows, createChart, createString, prettyString,
prettyTable, rowDominance, rowDominance2, sortVector,
sortMatrix, writePrimeimp and writeSolution
are internal functions of the QCA package which are not designed to be called directly
by the user. All of them are used by the eqmcc function, except
sortMatrix which is used by allExpressions. The verification and error
messages have been moved to the internal functions verify.data and verify.tt.