This library implements the comparative methodology as described in Ragin (1987) and Ragin (2000).
The analysis is the bridge between the qualitative and quantitative worlds, making use of the
qualitative procedures in a systematic, algorithmic way (therefore increasing the "confidence"
in the results, as understood by quantitative researchers).
The ''exact'' Quine-McCluskey algorithm for crisp sets is implemented, both for bvQCA (binary-value QCA)
and for mvQCA (multi-value QCA).
Starting with version 0.4-5 the package has a new function called "eqmcc" (from "E"nhanced
Quine-McCluskey) that finds exact solutions with a substantially lower memory consumption,
and from version 0.6-0 this function also performs mvQCA.
The next versions of the package will have more functions to address fsQCA (fuzzy-sets QCA) and to
deal with missing values in the data.
As of version 0.1-3 there is also a graphical user interface in the package QCAGUI.
Arguments
Details
ll{
Package: QCA
Type: Package
Version: 0.6-2
Date: 2009-09-23
License: GPL version 2 or newer
}
References
Ragin, Charles C. (1987) The Comparative Method. Moving beyond qualitative and
quantitative strategies, Berkeley:University of California Press
Dusa, Adrian (2007) A mathematical solution to the boolean minimization problem, available on
http://www.compasss.org/files/WPfiles/Dusa2007.pdf
Dusa, Adrian (2007a) Enhancing Quine-McCluskey, http://www.compasss.org/files/WPfiles/Dusa2007a.pdf