createMatrix: Create a base matrix for the truth table
Description
The truth table consists from all combinations of presence/absence of conditions (coded binary 1/0).
There are $2^k$ such combinations and this function should be among the fastests to create this
matrix, using ideas inspired from expand.grid
Usage
createMatrix(cond)
Arguments
cond
the number of conditions from the dataset
References
Ragin, Charles C. 1987 The Comparative Method. Moving beyond qualitative
and quantitative strategies, Berkeley: University of California Press