Learn R Programming

QCA (version 0.2-2)

solveChart: Reduce the redundant prime implicants

Description

While the minimization procedure find a certain number of prime implicants but not all of them are necessary as some are already covered by others (therefore redundant). This function further reduces the number of prime implicants for a minimum solution.

Usage

solveChart(chart)

Arguments

chart
the prime implicants chart, a matrix with TRUE/FALSE values

Value

  • a matrix containing row indices of all possible solutions

References

Ragin, Charles C. 1987 The Comparative Method. Moving beyond qualitative and quantitative strategies, Berkeley: University of California Press

See Also

'createChart'

Examples

Run this code
# the chart we're trying to further reduce
chart <- createChart(c("A", "B", "c"), c("ABC", "Abc", "AbC", "aBc"))
prettyTable(chart)

solveChart(chart)

## two minimum solutions: first and second or first and third prime implicants

Run the code above in your browser using DataLab