For any number of conditions, there is a finite number of possible combinations of presence/absence.
This function finds the observed combinations among all possible ones, prints the frequency
of each observed combination and establishes the value for the outcome in this way:
- if all observed combinations agree on having the same outcome value (either 0 or 1), then the
value for the outcome will be set to that value
- for any given combination, if the outcome present values of both 0 and 1 then the value for the
outcome will be set to a contradiction ("C")
- for all other possible combinations, the outcome is missing and will be coded with "?"
the name of the conditions from the dataset (if not specified, all variables
but the outcome are considered conditions)
quiet
print the truth table on the screen or return it invisibly
show.cases
show the rownames from the original dataset for each combination of conditions
complete
prints the complete truth table, including the missing combinations
Value
An object of class "truthTable", which is essentially a list with three components:
- tt: the truth table itself
- indexes: a vector with the base 10 representation of the truth table's lines
- noflevels: a vector with the number of levels from all input variables
References
Ragin, Charles C. 1987 The Comparative Method. Moving beyond qualitative
and quantitative strategies, Berkeley: University of California Press
data(Osa)
# print the truth tabletruthTable(Osa, outcome="OUT", show.cases=TRUE)
# print the complete truth tabletruthTable(Osa, outcome="OUT", show.cases=TRUE, complete=TRUE)